/************************************************************************/
/*																		*/
/*	DACSPI1.h	--	Declaration for DACSPI1 library 	    			*/
/*																		*/
/************************************************************************/
/*	Author:		Cristian Fatu											*/
/*	Copyright 2012, Digilent Inc.										*/
/************************************************************************/
/*  File Description:													*/
/*	This file declares the DACSPI1 library functions and the constants	*/
/*	involved.															*/
/*																		*/
/************************************************************************/
/*  Revision History:													*/
/*																		*/
/*	01/16/2012(CristianF): created										*/
/*  06/19/2012(MichaelK) : Made floating point calculations conditional */
/*                         compilatioin                                 */
/*																		*/
/************************************************************************/
#if !defined(DACSPI1_H)
#define DACSPI1_H

#define DA1_FLOATING_POINT

/* ------------------------------------------------------------ */
/*				Include File Definitions						*/
/* ------------------------------------------------------------ */
#include <inttypes.h>
#include <DSPI.h>

/* ------------------------------------------------------------ */
/*					Definitions									*/
/* ------------------------------------------------------------ */
#define DACSPI1_NO_BITS		8

#define DACSPI1_SPI_FREQ	1000000 // 1 MHz - default spi freq
#define	PAR_ACCESS_SPI0			0
#define	PAR_ACCESS_SPI1			1
#define	PAR_ACCESS_I2C			2	

#define DACSPI1_CTRL_BYTE	0x00	// selecting convertor DAC A to be written
/* ------------------------------------------------------------ */
/*					Errors Definitions							*/
/* ------------------------------------------------------------ */

#define DACSPI1_ERR_SUCCESS				0	// The action completed successfully
#define DACSPI1_ERR_VAL_OUT_OF_RANGE	1	// The value is out of range

/* ------------------------------------------------------------ */
/*					Procedure Declarations						*/
/* ------------------------------------------------------------ */


class DACSPI1 {
private: 
	DSPI *pdspi;
	uint8_t m_SSPin;

public:
	uint8_t WriteIntegerValue(uint8_t bIntegerValue);

#ifdef DA1_FLOATING_POINT
	uint8_t WritePhysicalValue(float dPhysicalValue, float dReference = 3.3);
#endif
	
	DACSPI1();
	void begin(uint8_t bAccessType);
};



#endif
