/************************************************************************/
/*				                        		                        */
/*	  DACSPI1DemoProject 		                                        */
/*						                  	                            */
/*					                        	                        */
/************************************************************************/
/*	Author: Cristian Fatu						                        */
/*	Copyright 2012, Digilent Inc.					                    */
/************************************************************************/
/*  File Description: 			             		                    */
/*					                        	                        */
/* This file implements a simple demo application that demonstrates     */
/* how to use the DACSPI1 library.				                        */
/*									                                    */
/*	Functionality:							                            */
/*									                                    */
/* In the setup() function, the application initializes                 */
/* the DACSPI1 library object.                                          */
/* In the loop() function, the application repeatedly increases and     */
/* decreases the physical value to be reconstructed by the DA converter.*/
/*					                        	                        */
/*	Required Hardware:						                            */
/*	  1. Cerebot MX4cK    					                            */
/*	  2. PmodDA1 - plugged into upper row of the JB connector 			*/
/*			(SPI0 interface) signal is produced on DA1 J2 pins A1 and A2*/
/************************************************************************/
/*  Revision History:			        			                    */
/*					                        	                        */
/*	01/16/2012(CristianF): created	       			                    */
/*  06/19/2012(MichaelK) : Made floating point calculations conditional */
/*                         compilation                                  */
/*						                     	                        */
/************************************************************************/

/* -------------------------------------------------------------------- */
/*				Include File Definitions                     	        */
/* -------------------------------------------------------------------- */
#include <DACSPI1.h>
// DSPI librariy header must be included in the sketch

#include <DSPI.h>
/* -------------------------------------------------------------------- */
/*				Global Variables		        */
/* -------------------------------------------------------------------- */
  DACSPI1 myDACSPI1; // the library object
  float dMaxValue = 3;
  float dMinValue = 0;
  float dStep = 0.05;
  float dValue;

/* -------------------------------------------------------------------- */
/*	               Procedure Definitions	                        */
/* -------------------------------------------------------------------- */
/***	setup
**
**	Parameters:
**		none
**
**	Return Value:
**		none
**
**	Errors:
**		none
**
**	Description:
**		 Performs basic initialization.		
/*** ---------------------------------------------------------- ***/
void setup()
{ 
  // initialize PmodDACSPI1 on SPI
  myDACSPI1.begin(PAR_ACCESS_SPI0); // corresponds to DSPI0 - connector JB
//  myDACSPI1.begin(PAR_ACCESS_SPI1); // corresponds to DSPI1 - connector J1
}

/*** ---------------------------------------------------------- ***/
/***	loop
**
**	Parameters:
**		none
**
**	Return Value:
**		none
**
**	Errors:
**		none
**
**	Description:
**		Main program module. Enters the main program loop.
/*** ---------------------------------------------------------- ***/
void loop()
{ 
  // increase physical value from minimum to maximum value 
  for(dValue = dMinValue; dValue <= dMaxValue; dValue += dStep)
  {
    // send value to the DA converter
    myDACSPI1.WritePhysicalValue(dValue);
    // wait some time
    delay(200);
  }


  // decrease physical value from maximum to minimum value
  for(dValue = dMaxValue; dValue >= dMinValue; dValue -= dStep)
  {
    // send value to the DA converter
    myDACSPI1.WritePhysicalValue(dValue);
    // wait some time
    delay(200);
  }
}
